@@ -12,7 +12,7 @@ use Time::HiRes qw ( time sleep );
 use HTTP::Tiny;
 use HTTP::Daemon 6.05; # Our log server needs this, but we load it here to find its version
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 =head1 NAME
 
@@ -196,8 +196,7 @@ sub spawn {
   my @opts = ("-f", $url_file);
   push @opts, "-e" => delete($args{ eval })
       if $args{ eval };
-  push @opts, "-s" => $args{ request_pause }
-      if $args{ request_pause };
+  push @opts, "-s" => $args{ request_pause };
 
   my @cmd=( $^X, $server_file, $web_page, $logfile, @opts );
   my $pid = $self->spawn_child(@cmd);
